#' @title Manage appenders for loggers
#'
#' @description See \code{futile.logger::\link[futile.logger]{flog.appender}} for details.
#'
#' @name flog.appender
#' @keywords internal
#' @export
#' @importFrom futile.logger flog.appender
NULL

#' @title Manage logger layouts
#'
#' @description See \code{futile.logger::\link[futile.logger]{flog.layout}} for details.
#'
#' @name flog.layout
#' @keywords internal
#' @export
#' @importFrom futile.logger flog.layout
NULL

#' @title Manage loggers
#'
#' @description See \code{futile.logger::\link[futile.logger]{flog.logger}} for details.
#'
#' @name flog.logger
#' @keywords internal
#' @export
#' @importFrom futile.logger flog.logger
NULL

